@@ -12,31 +12,17 @@
 
 #include <KAboutData>
 #include <KCrash>
-
 #include <KLocalizedString>
+#include <KGameDifficulty>
+#include <KDBusService>
 
-#include <KgDifficulty>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <kdelibs4configmigrator.h>
-#endif
 #include <QApplication>
 #include <QCommandLineParser>
 #include <QStandardPaths>
-#include <KDBusService>
 
 int main(int argc, char **argv)
 {
-    // Fixes blurry icons with fractional scaling
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
-#endif
     QApplication app(argc, argv);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    Kdelibs4ConfigMigrator migrate(QStringLiteral("kdiamond"));
-    migrate.setConfigFiles(QStringList() << QStringLiteral("kdiamondrc") << QStringLiteral("kdiamond.notifyrc"));
-    migrate.setUiFiles(QStringList() << QStringLiteral("kdiamondui.rc"));
-    migrate.migrate();
-#endif
 
     KLocalizedString::setApplicationDomain("kdiamond");
     KAboutData about(QStringLiteral("kdiamond"), i18nc("The application's name", "KDiamond"),
@@ -62,9 +48,9 @@ int main(int argc, char **argv)
     //resource directory for KNewStuff2 (this call causes the directory to be created; its existence is necessary for the downloader)
     QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QLatin1String("/themes/");
 
-    Kg::difficulty()->addStandardLevelRange(
-        KgDifficultyLevel::VeryEasy,
-        KgDifficultyLevel::VeryHard
+    KGameDifficulty::global()->addStandardLevelRange(
+        KGameDifficultyLevel::VeryEasy,
+        KGameDifficultyLevel::VeryHard
     );
     KDBusService service;
     // see if we are starting with session management
